#
# spec file for package perl-Event
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Event
Name:           perl-Event
Version:        1.28
Release:        1.15
Summary:        Event loop processing
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETJ/%{cpan_name}-%{version}.tar.gz
Source1:        perl-Event-rpmlintrc
Source2:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
ALERT: Marc Lehmann may have taken over the future of event loops in Perl.
Check out his libev library and EV Perl module. 25 Aug 2009

The Event module provide a central facility to watch for various types of
events and invoke a callback when these events occur. The idea is to delay
the handling of events so that they may be dispatched in priority order
when it is safe for callbacks to execute.

Events (in the ordinary sense of the word) are detected by *watchers*,
which reify them as *events* (in the special Event module sense). For
clarity, the former type of events may be called "source events", and the
latter "target events". Source events, such as signals arriving, happen
whether or not they are being watched. If a source event occurs which a
watcher is actively watching then the watcher generates a corresponding
target event. Target events are only created by watchers. If several
watchers are interested in the same source event then each will generate
their own target event. Hence, any particular source event may result in
zero, one, two, or any number of target events: the same as the number of
watchers which were actively watching for it.

Target events are queued to be processed in priority order (priority being
determined by the creating watcher) and in FIFO order among events of the
same priority. Queued ("pending") events can, in some cases, be cancelled
before being processed. A queued event is processed by being passed to the
callback function (or method on a particular object or class) which was
specified to the watcher.

A watcher, once created, operates autonomously without the Event user
having to retain any reference to it. However, keeping a reference makes it
possible to modify most of the watcher's characteristics. A watcher can be
switched between active and inactive states. When inactive, it does not
generate target events.

Some types of source event are not reified as target events immediately.
Signals received, for example, are counted initially. The counted signals
are reified at certain execution points. Hence, signal events may be
processed out of order, and if handled carelessly, on the wrong side of a
state change in event handling. A useful way to view this is that
occurrence of the source event is not actually the arrival of the signal
but is triggered by the counting of the signal.

Reification can be forced when necessary. The schedule on which some other
events are created is non-obvious. This is especially the case with
watchers that watch for a condition rather than an event. In some cases,
target events are generated on a schedule that depends on the operation of
the event loop.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ANNOUNCE Changes README README.EV TODO Tutorial.pdf Tutorial.pdf-errata.txt util

%changelog
* Fri Apr 30 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.28
  see /usr/share/doc/packages/perl-Event/Changes
  1.28 2021-04-29
  - remove C-only restriction on ->Inline method - thanks @oodler577
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.27
  see /usr/share/doc/packages/perl-Event/Changes
  1.27 2018-11-17
  - only Zero(Polld) if not NULL (reported by @andk, thanks!)
* Thu Jun 23 2016 coolo@suse.com
- updated to 1.26
  see /usr/share/doc/packages/perl-Event/Changes
  1.26 2015-06-13
  - fix doc typos (Lucas Kanashiro)
* Sun Jun 12 2016 coolo@suse.com
- updated to 1.25
  see /usr/share/doc/packages/perl-Event/Changes
* Sun Apr 19 2015 coolo@suse.com
- updated to 1.24
  see /usr/share/doc/packages/perl-Event/ChangeLog
- remove broken Event-1.0-warning.patch
* Mon Jul 28 2014 coolo@suse.com
- updated to 1.23, no Changelog provided
* Tue Jul 15 2014 chris@computersalat.de
- fix build for SLE_11
  * reactivate Event-1.0-warning.patch
* Tue Jun  4 2013 coolo@suse.com
- updated to 1.21, no Changelog provided
* Mon Sep 19 2011 coolo@suse.com
- updated to 1.20, no Changelog provided
* Mon Jun 20 2011 coolo@novell.com
- updated to 1.17, no Changelog provided
* Wed May  4 2011 coolo@opensuse.org
- updated to 1.15, no Changelog provided
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Apr  7 2010 chris@computersalat.de
- update to 1.13
  o no ChangeLog :(
- cleanup spec
  o sort TAGS
  o updated Url
  o fixed deps
- added perl-macros
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Fri Sep 12 2008 garloff@suse.de
- Update to 1.11:
  * bugfix in db_show_timeables
  * times are now using NV type
  * Moved idle2 testcase to demos
  * io testcase fixed for Darwin
* Tue Jul 17 2007 garloff@suse.de
- Update to 1.09 (no real code changes)
* Tue Apr 24 2007 ro@suse.de
- update to 1.08
  * Add casts to quell warnings as suggested by JDHEDDEN@cpan.org.
  * Marc Lehmann suggests using mg_ptr instead
  of mg_obj. Sounds good to me.
  * Fix 64 bit issue.  Encouraged by Eric Rybski
  * Fix ancient memory leak in loop() noticed by Nikita Savin
  * Preliminary /dev/poll support from Michael Pergament
  As of yet, there is no config test to
  turn on this code.  Patches welcome.
  * Apply Win32 patch from Graciliano M. P. <gmpowers@terra.com.br>.
  * Generic watchers: implementation, documentation, and tests.
  * Documentation refinements.
  * Event.xs: Due to popular demand, queue_pending() is now a public
  API, for better or worse.  Beware of race conditions.
  * A var watcher can currently be created with no variable to
  watch, provided of course that it is parked.  However, once a
  variable has been set, the watcher cannot be returned to the
  no-variable state.  The variable to watch can be changed, but the
  watcher rejects any attempt to set the reference to undef.
  * Applied a patch to allow the variable reference of a var watcher
  to be set to undef.
  * Applied patch to clarify the documentation (with tweaks from
  Joshua).
* Thu Apr 19 2007 ro@suse.de
- import from 9.2 (needed by iwatch)
* Mon Aug 16 2004 garloff@suse.de
- Update to Event-1.00:
  * c/watcher.c: Check for a missing callback.
  * lib/Event.pm: Make NO_TIME_HIRES actually work.
  * c/signal.c: iClear signal counter when a signal watcher stops.
- Update to Event-0.88:
  * lib/Event.pm: Simplify hooking into Time::HiRes.
  * Event.xs: Remove U2time. Remove install_time_api().
  * Various Event docu updates.
  * c/watcher.c: Fix SEGV reported by Zefram; add test.
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 14 2003 garloff@suse.de
- Install into %%perl_vendorlib, _vendorarch, use _process_packlist.
- Update to Event-0.87:
  Fix tracevar_r, tracevar_w delcarations.
  (Fix was in SuSE patch before.)
* Sun May 25 2003 ro@suse.de
- remove unpackaged files from buildroot
* Wed Aug 28 2002 prehak@suse.cz
- disabled make test on ppc64 and s390x
* Fri Aug  9 2002 mls@suse.de
- fixed tracevar_r/w callbacks to work with threaded perl
* Tue Jul  2 2002 garloff@suse.de
- Update to Event-0.86:
  * IRIX/Solaris tweaks
  * Avoid infinite polling loops on some select() implementations
* Thu Jan 17 2002 garloff@suse.de
- Create package perl-Event (0.83)
  It's needed by Perl Object Environment (perl-POE).
